import json
from jose import jwt

import requests




class accessToken:
    def __init__(self,token):
        self.token=token;
       
       
    def decodePayload(self):
        
        res=requests.get("https://api.secuuth.io/tokens/jwks")

        data=res.json()
        
        

        try:
            payload = jwt.decode(self.token,data,algorithms='RS256', options= {'verify_exp':True,'verify_aud': False,})
            #payload = jwt.decode(self.token,data,algorithms='RS256')
            return payload
        except:
            print("not verified")
            return {}

    def getSub(self):
        payload=self.decodePayload();
        return payload.get('sub')
    def getAud(self):
        payload=self.decodePayload();
        return payload.get('aud')
    def getIss(self):
        payload=self.decodePayload();
        return payload.get('iss')
    def getExp(self):
        payload=self.decodePayload();
        return payload.get('exp')
    def getJti(self):
        payload=self.decodePayload();
        return payload.get('jti')
    def getTyp(self):
        payload=self.decodePayload();
        return payload.get('typ')
    def getSignInMode(self):
        payload=self.decodePayload();
        return payload.get('signInMode')
    def getUserId(self):
        payload=self.decodePayload();
        return payload.get('userId')
    def getScope(self):
        payload=self.decodePayload();
        return payload.get('scope')
    def getIat(self):
        payload=self.decodePayload();
        return payload.get('iat')
    
    
        
        
  

    


import json
import requests

RENEWURL = "http://loclhost:5000/auth/renewTokens"
class renewToken:
     def __init__(self,pubKey,refreshToken,keyId,userSubId):
        self.pubKey=pubKey
        self.refreshToken=refreshToken
        self.keyId=keyId
        self.userSubId=userSubId
    

    
     def renewToken(self):
         
         try: 
            token=requests.post(RENEWURL,
                    data=json.loads({
                    "publicKey":self.pubKey,
                    "refreshToken":self.refreshToken,
                    "userSubId":self.userSubId,
                    "renewRefreshToken":False,
                    }),headers=json.loads({ 
                    "Content-Type": "application/json",
                     "keyId":self.keyId
                    }))
            return token;
         except:
            return{}

            

        

         
            



        




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="secuuthTokenPythonSdk",
    version="1.5",
    author="secuuth",
    author_email="amitoshkumar10@gmail.com",
    description="secuuth  SDK for python scripts",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/engineering-secuuth/secuuth-jwt-python-sdk",
    packages=["pySdk"],
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=["requests", "python-jose"]
)
